// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package container

import (
	"github.com/kataras/iris/v12/context"
	"reflect"
)

const (
	ServicesPackageName            = "services"
	ServiceNameSuffix              = "Service"
	PathSeparator                  = "/"
	HttpPost            HttpMethod = "POST"
	HttpPut             HttpMethod = "POU"
	HttpGet             HttpMethod = "Get"
	HttpDelete          HttpMethod = "DELETE"
)

var ServiceNameSuffixLength = len([]rune(ServiceNameSuffix))

type HttpMethod string

type (
	// 调用器
	// 参数
	// 1.参数列表
	// 返回值:
	// 1.返回值列表
	Caller = func([]reflect.Value) []reflect.Value
	// 路由
	Router = context.Handler
)

// 空参数列表
var emptyParameters []reflect.Value

// *error 类型常量
var errorType = reflect.TypeOf((*error)(nil)).Elem()


// Caller相等性判断
// 参数
// 1.比较对象1
// 3.比较对象2
// 返回值:
// 1.判断结果
func CallerEqual(caller1 Caller, caller2 Caller) bool {
	if caller1 == nil {
		if caller2 == nil {
			return true
		} else {
			return false
		}
	} else {
		if caller2 == nil {
			return false
		} else {
			return reflect.ValueOf(caller1).Pointer() == reflect.ValueOf(caller2).Pointer()
		}
	}
}
