package middleware

import (
	"LAPP_AS/global"
	"LAPP_AS/infra/logger/logger"
	"LAPP_AS/web/supports"
	"fmt"
	"github.com/kataras/iris/v12"
	"net/http"
	"runtime"
)

func Recover(ctx iris.Context) {
	defer func() {
		if err := recover(); err != nil {
			log, _ := logger.NewLogger(global.ProjectID, "Recover", "Recover")
			if ctx.IsStopped() {
				return
			}

			var stacktrace string
			for i := 1; ; i++ {
				_, f, l, got := runtime.Caller(i)
				if !got {
					break
				}
				stacktrace += fmt.Sprintf("%s:%d\n", f, l)
			}

			errMsg := fmt.Sprintf("错误信息: %s", err)
			// when stack finishes
			logMessage := fmt.Sprintf("从错误中回复：('%s')\n", ctx.HandlerName())
			logMessage += errMsg + "\n"
			logMessage += fmt.Sprintf("\n%s", stacktrace)
			// 打印错误日志
			log.Error(logMessage)
			// 返回错误信息
			supports.Error(ctx, http.StatusInternalServerError, "系统未知错误", nil)
			ctx.StopExecution()
		}
	}()
	ctx.Next()
}
